@@ -56,6 +56,10 @@ class Phase:
         logfile = os.path.join(self.simfolder, "calphy.log")
         self.logger = ph.prepare_log(logfile)
 
+        self.logger.info("---------------input file----------------")
+        self.logger.info(yaml.safe_dump(self.calc.to_dict()))
+        self.logger.info("------------end of input file------------")
+
         if self.calc._pressure is None:
             pressure_string = "None"
         else:
@@ -660,7 +664,7 @@ class Phase:
         pf = lf*pi
 
         #create lammps object
-        lmp = ph.create_object(self.cores, self.simfolder, self.calc.md.timestep)
+        lmp = ph.create_object(self.cores, self.simfolder, self.calc.md.timestep, self.calc.md.cmdargs)
 
         lmp.command("echo              log")
         lmp.command("variable          li equal %f"%li)
@@ -835,7 +839,7 @@ class Phase:
         pf = lf*p0
 
         #create lammps object
-        lmp = ph.create_object(self.cores, self.simfolder, self.calc.md.timestep)
+        lmp = ph.create_object(self.cores, self.simfolder, self.calc.md.timestep, self.calc.md.cmdargs)
 
         lmp.command("echo              log")
         lmp.command("variable          li equal %f"%li)
@@ -919,7 +923,7 @@ class Phase:
         pf = self.calc._pressure_stop
 
         #create lammps object
-        lmp = ph.create_object(self.cores, self.simfolder, self.calc.md.timestep)
+        lmp = ph.create_object(self.cores, self.simfolder, self.calc.md.timestep, self.calc.md.cmdargs)
 
         lmp.command("echo              log")
         lmp.command("variable          li equal %f"%li)
